/// <reference types="got" />
import { ObjectId } from 'bson';
import { MarketplaceServiceNames } from '../to-be-removed/types';
import { Environment } from '../bootstrapping/environment';
import { EveClient } from './eve-client';
import { ApiCarrierName } from './settings-client';
export declare type ApiFulfillmentStatus = 'Registered' | 'Shipped' | 'AtDepot' | 'Delivered' | 'Canceled' | 'Failed' | 'OutForDelivery';
interface IMonetaryValue {
    value: number;
    currency: string;
}
interface IParcelShop {
    parcelShopIdentification: string;
    parcelShopBranchCode: string;
}
interface IPackageItem {
    marketplaceItemId: string;
    marketplaceOrderId: string;
    quantity: number;
}
export interface IPackage {
    number?: string;
    fullNumber?: string;
    weight: number;
    items: IPackageItem[];
}
export interface ApiFulfillment {
    _id?: string;
    companyId: ObjectId;
    marketplaceOrderIds: string[];
    fulfillmentId?: string;
    marketplace: MarketplaceServiceNames;
    status: ApiFulfillmentStatus;
    carrier?: ApiCarrierName;
    shipDate?: Date;
    trackingNumber?: string;
    carrierName?: string;
    shipMethod?: string;
    trackingUrl?: string;
    cashOnDelivery?: IMonetaryValue;
    shipmentValue?: IMonetaryValue;
    parcelShop?: IParcelShop;
    packages?: IPackage[];
    syncError?: string;
}
export declare type ApiInputFulfillment = Omit<ApiFulfillment, '_id'>;
export declare class FulfillmentsClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    updateFulfillments(companyId: ObjectId, fulfillments: ApiFulfillment[]): Promise<void>;
    updateFulfillmentById(fulfillmentId: string | ObjectId, fulfillment: ApiInputFulfillment): Promise<ApiFulfillment>;
    getFulfillmentById(fulfillmentId: string): Promise<ApiFulfillment>;
    confirmFulfillmentById(fulfillmentId: string, syncError?: string): Promise<import("got").Response<any>>;
    getFulfillment(companyId: ObjectId, marketplace: MarketplaceServiceNames, marketplaceOrderId: string): Promise<ApiFulfillment | null>;
    confirmFulfillment(companyId: ObjectId, marketplace: MarketplaceServiceNames, marketplaceOrderId: string, syncError?: string): Promise<import("got").Response<any>>;
}
export {};
