import { EveClient } from './eve-client';
import { ApiOrderStatus, Environment } from '..';
import { ObjectId } from 'bson';
import { MallServiceNames } from '../to-be-removed/types';
import { ApiFulfillmentStatus } from './fulfillments-client';
export interface ApiMallFulfillment {
    companyId: ObjectId;
    marketplaceOrderId: string;
    marketplace: MallServiceNames;
    trackingNumber: string;
    trackingUrl: string;
    status: ApiFulfillmentStatus;
}
export interface ApiMallFulfillmentResponse {
    fulfilled: boolean;
    correctOrderStatus?: ApiOrderStatus;
    syncError?: string;
}
export declare class MallServiceClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getDeliveryMethods(companyId: ObjectId): Promise<ApiMallDeliveryMethod[]>;
    fulfillOrder(companyId: ObjectId, fulfillment: ApiMallFulfillment): Promise<ApiMallFulfillmentResponse>;
    getCredentials(companyId: ObjectId, marketplace: MallServiceNames): Promise<ApiMallCredentials>;
    updateCredentials(companyId: ObjectId, marketplace: MallServiceNames, authorizationKey: string, active: boolean): Promise<ApiMallDeliveryMethod[]>;
    deleteCredentials(companyId: ObjectId, marketplace: MallServiceNames): Promise<ApiMallCredentials>;
    getStatuses(companyId: ObjectId): Promise<{
        marketplace: MallServiceNames;
        status: 'online' | 'offline';
    }[]>;
}
export interface ApiMallDeliveryMethod {
    code: string;
    title: string;
    marketplace: MallServiceNames;
    isPickupPoint: boolean;
}
export interface ApiMallCredentials {
    companyId: ObjectId;
    authorizationKey: string;
    webhookId: string;
    marketplace: MallServiceNames;
    active: boolean;
}
