import { EveClient } from './eve-client';
import { Environment } from '../bootstrapping/environment';
import { AmazonServiceNames, MarketplaceServiceNames } from '../to-be-removed/types';
import { ObjectId } from 'bson';
import { ApiBarcode } from '../products/parse-barcode';
export interface ApiShallowPricing {
    found: boolean;
    isAlone: boolean;
    isCheaper: boolean;
    isPricier: boolean;
    isPricierWithinThreshold: boolean;
    freeShipping: boolean;
}
export interface IMwsCredentials {
    accessKey: string;
    secretKey: string;
    sellerId: string;
    token: string;
}
export interface ApiPrice {
    base: number;
    selling?: number;
    min?: number;
    max?: number;
}
export interface ApiVariant {
    companyId: ObjectId;
    sku: string;
    marketplaceSkus?: {
        emag: string;
    };
    barcode: ApiBarcode;
    image?: string;
    name: string;
    stock: number;
    prices: {
        [key in MarketplaceServiceNames]?: ApiPrice;
    };
    removedAt?: Date;
    asins: {
        [key in AmazonServiceNames]?: string;
    };
    shippingTemplate?: string;
    locks?: string[];
    updatedAt?: Date;
    daysToShip?: number;
    /**
     * Parent product info
     */
    parent?: string;
    /**
     * Alza specific parameter
     */
    ecoFee?: number;
}
export declare const MwsCredentialsJoi: import("joi").ObjectSchema;
export declare class ProductPricingClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getPricing(marketplace: MarketplaceServiceNames, asins: string[], sellerId?: string): Promise<any>;
    getShallowPricing(marketplace: MarketplaceServiceNames, credentials: IMwsCredentials, variants: ApiVariant[]): Promise<ApiShallowPricing[]>;
}
