import { ObjectId } from 'bson';
import { EveClient } from './eve-client';
import { Environment } from '../bootstrapping/environment';
import { MarketplaceServiceNames } from '../to-be-removed/types';
export declare class SettingsClient extends EveClient {
    protected env: Environment;
    constructor(env: Environment);
    getOrCreate(companyId: ObjectId): Promise<ApiSyncSettings>;
}
export interface ApiAutopricingSettings {
    active: boolean;
    autoActivation: boolean;
    progressStrategy: number;
    fallbackStrategy: number;
    penaltyDrain: number;
    amplification: number;
    countInShipping: boolean;
    defaultTopCap: number;
    defaultBottomCap: number;
}
export interface ApiVatRateSettings {
    rate: number;
}
export declare type GenericCarrierName = 'AFLFedex' | 'Aramex' | 'BluePackage' | 'BlueDart' | 'CanadaPost' | 'Chronopost' | 'CityLink' | 'DHL' | 'DHLGlobalMail' | 'DPD' | 'DTDC' | 'Delhivery' | 'DeutschePost' | 'FEDEXJP' | 'Fastway' | 'FedEx' | 'FedExSmartPost' | 'FirstFlight' | 'GLS' | 'GO' | 'HermesLogistikGruppe' | 'IndiaPost' | 'JPEXPRESS' | 'LaPoste' | 'Lasership' | 'NITTSU' | 'Newgistics' | 'NipponExpress' | 'OSM' | 'OnTrac' | 'OverniteExpress' | 'Parcelforce' | 'Parcelnet' | 'PosteItaliane' | 'Professional' | 'RoyalMail' | 'SAGAWA' | 'SDA' | 'SagawaExpress' | 'Smartmail' | 'Streamlite' | 'TNT' | 'Target' | 'UPS' | 'UPSMI' | 'UPSMailInnovations' | 'USPS' | 'YAMATO' | 'YamatoTransport' | 'Other';
export declare const GENERIC_CARRIER_NAMES: GenericCarrierName[];
export declare type AlzaCarrierName = 'COURIER' | 'CZPOSTD' | 'CZPOSTP' | 'CZPOSTB' | 'DHL' | 'DPD' | 'FOFRSTD' | 'GEIS' | 'GEISPOINT' | 'GEISCARGO' | 'GLS' | 'GO' | 'MagyarPOSTHD' | 'MagyarPOSTPO' | 'MagyarPOSTPP' | 'MagyarPOSTPT' | 'PPL' | 'PPLPARCELSHOP' | 'RHENUS' | 'SKPOSTD' | 'SKPOSTP' | 'SKYNET' | 'TOPTRANS' | 'UPS' | 'HELICARUP' | 'HELICARSTD' | 'ZASILKOVNA' | 'ZavolejSiKuryra' | 'Supplier';
export declare const ALZA_CARRIER_NAMES: AlzaCarrierName[];
export declare type ApiCarrierName = GenericCarrierName | AlzaCarrierName;
export declare const API_CARRIER_NAMES: ApiCarrierName[];
export interface ApiMallSettings {
    synchronizePrices: boolean;
    synchronizeStock: boolean;
}
export interface ApiAmazonSettings {
    synchronizePrices: boolean;
    synchronizeStock: boolean;
    listNewProducts: boolean;
    downloadPricing: boolean;
    zeroUnmatchedProducts: boolean;
    ignoreZeroStockProducts: boolean;
}
export interface ApiEmagSettings {
    listNewProducts: boolean;
    ignoreZeroStockProducts: boolean;
}
export interface ApiSyncSettings {
    companyId: ObjectId;
    formulas: {
        [key in MarketplaceServiceNames]?: ApiFormula;
    };
    japoId: string;
    autopricing?: {
        [key in MarketplaceServiceNames]?: ApiAutopricingSettings;
    };
    vatRates?: {
        [key in MarketplaceServiceNames]?: ApiVatRateSettings;
    };
    mall?: ApiMallSettings;
    amazon?: ApiAmazonSettings;
    emag?: ApiEmagSettings;
}
export interface ApiFormula {
    add: number;
    multiply: number;
}
