/// <reference types="got" />
import { EveClient } from './eve-client';
import { ObjectId } from 'bson';
import { Environment, ApiOrder, CurrencyCode } from '..';
import { ApiImportSettings } from '../settings/import-settings-model';
export declare class ShoptetServiceClient extends EveClient {
    constructor(env: Environment);
    postOrders(companyId: ObjectId, orders: ApiOrder[], settings: ApiImportSettings): Promise<import("got").Response<any>>;
    getShoptetShipmentMethods(companyId: ObjectId, addon?: Addon): Promise<IShoptetShipmentMethod[]>;
    createShoptetShipmentMethod(companyId: ObjectId, shipmentMethod: ApiShoptetShipmentMethodInput): Promise<IShoptetShipmentMethod>;
    getShoptetOrderStatuses(companyId: ObjectId): Promise<IShoptetOrderStatus[]>;
    syncShoptetOrders(companyId: ObjectId, importSettings: ApiImportSettings[]): Promise<any>;
    getApiAccessToken(companyId: ObjectId, addon?: string): Promise<ApiShoptetAccessToken>;
    getShopInfo(companyId: ObjectId): Promise<ApiShop>;
    getShoptetPaymentMethods(companyId: ObjectId): Promise<ApiShoptetPaymentMethod[]>;
}
export declare enum Addon {
    Amazon = "amazon",
    Alza = "alza",
    Mall = "mall"
}
export interface ApiShopAddon {
    oAuthToken: string;
    active: boolean;
}
export interface ApiShopBillingInformation {
    companyId: string;
    taxId?: string;
}
export interface ApiShop {
    companyId: ObjectId;
    addons: {
        [key in Addon]?: ApiShopAddon;
    };
    shopId: number;
    hostname: string;
    urls: Record<string, string>;
    currencies: CurrencyCode[];
    endpoints: ApiShopEndpoints;
    billingInformation?: ApiShopBillingInformation;
}
export declare type ApiShopEndpoints = {
    [key in Addon]: ApiShoptetSystemEndpoint[];
};
export interface ApiShoptetAccessToken {
    companyId: ObjectId;
    accessToken: string;
    expiresAt: Date;
    lastUsedAt: Date;
    addon: string;
}
export declare enum SHOPTET_SHIPPING_COMPANY_CODES {
    INTIME = "intime",
    OWN = "own-transport",
    CZECH_POST = "ceska-posta",
    PERSONAL_COLLECTION = "personal-collection",
    PPL_CZ = "ppl-cz",
    ULOZENKA = "ulozenka",
    ULOZENKA_HOME = "ulozenka-home"
}
export declare enum ENDPOINTS {
    SHIPPING_METHODS = "/shipping-methods",
    PAYMENT_METHODS = "/payment-methods"
}
export interface ApiShoptetShipmentMethodInput {
    name: string;
    shippingCompanyCode: SHOPTET_SHIPPING_COMPANY_CODES;
    description?: string;
    visibility?: boolean;
    wholesale?: boolean;
}
export interface ApiShoptetPaymentMethod {
    guid: string;
    name: string;
    description: string;
    paymentType: {
        id: number;
        code: string;
        name: string;
    };
    visible: boolean;
    priority: number;
    wholesale: boolean;
    logoUrl: string;
    eetEligible: boolean;
}
export interface IShoptetOrderStatus {
    code: number;
    order: number;
    name: string;
    markAsPaid: boolean;
}
export interface IShoptetShipmentMethod {
    guid: string;
    name: string;
    description: string;
    shippingCompany: {
        id: number;
        code: SHOPTET_SHIPPING_COMPANY_CODES;
        name: string;
    };
    visible: boolean;
}
export declare enum ApiShoptetSystemEndpointStatus {
    APPROVED = "approved",
    PENDING = "pending"
}
export interface ApiShoptetSystemEndpoint {
    endpoint: string;
    description: string;
    group: {
        id: number;
        description: string;
    };
    access: 'read' | 'write' | 'both';
    action: string | null;
}
