import { ObjectId } from 'bson';
import { ConsoleLogger } from './console-logger';
export declare type IncidentPriority = 'P0' | 'P1';
export interface IncidentReportDetails {
    incidentDetailsUrl?: string;
    timestamp?: Date;
    affectedCompanies?: (ObjectId | string)[];
}
/**
 * Simple component for reporting health of business processes in an uniform
 * way so that their status can be consumed easily by downstream components
 * (alert triggers, etc)
 */
export declare class HealthReporter {
    private consoleLogger;
    constructor(consoleLogger: ConsoleLogger);
    /**
     * Report the occurrence of an incident. This may result in a series
     * of alert messages sent by downstream components.
     */
    reportIncident(priority: IncidentPriority, summary: string, details?: IncidentReportDetails): void;
    /**
     * Report that a health check for given `healthMetric` was successfully
     * done. Absence of heartbeat series may result in an alarm situation
     * triggered by downstream components.
     */
    heartbeat(healthMetric: string): void;
}
